@@ -524,7 +524,7 @@ EOF
     if dims = arg[:dims]
       code << <<"EOF"
   {
-    int shape[#{dims.length}];
+    na_shape_t shape[#{dims.length}];
 EOF
       dims.each_with_index{|dim,k|
         get_vars(dim).each{|d|
@@ -553,7 +553,7 @@ EOF
       end
       code << <<"EOF"
   {
-    int shape[#{dims.length}];
+    na_shape_t shape[#{dims.length}];
 EOF
       dims.each_with_index{|dim,k|
         ds = get_vars(dim)
@@ -797,6 +797,12 @@ extern integer ilaenv_(integer* ispec, char* name, char* opts, integer* n1, inte
 static VALUE sHelp, sUsage;
 static VALUE #{RBPREFIX}ZERO;
 
+/* for compatibility for NArray and NArray with bigmem patch */
+#ifndef NARRAY_BIGMEM
+typedef int    na_shape_t;
+#endif
+
+
 EOF
   }
 
