@@ -1,3 +1,4 @@
+require "rubygems"
 require "mkmf"
 
 
@@ -61,18 +62,21 @@ unless find_library("lapack", nil)
   end
 end
 
-sitearchdir = RbConfig::CONFIG["sitearchdir"]
-dir_config("narray", sitearchdir, sitearchdir)
-gem_path = nil
-begin
-  require "rubygems"
-  if (spec = Gem.source_index.find_name("narray")).any?
-    gem_path = spec.last.full_gem_path
+if Gem.respond_to?(:find_files)
+  require "rbconfig"
+  so = RbConfig::CONFIG["DLEXT"]
+  narray_include = File.expand_path(File.dirname(Gem.find_files("narray.h")[0]))
+  narray_lib = File.expand_path(File.dirname(Gem.find_files("narray." + so)[0]))
+else
+  gem_home=(`gem environment GEM_HOME`).chomp
+  narray_dir = Dir.glob("#{gem_home}/gems/narray-*").sort[-1]
+  if narray_dir
+    narray_include = narray_lib = narray_dir
+  else
+    sitearchdir = RbConfig::CONFIG["sitearchdir"]
+    narray_include = narray_lib = [ $sitearchdir, $sitearchdir]
   end
-rescue LoadError
-end
-unless find_header("narray.h",gem_path) && have_header("narray_config.h")
-  header_not_found("narray")
 end
+dir_config('narray', narray_include, narray_lib)
 
 create_makefile("numru/lapack")
